<?php
namespace PME\Controllers\Cardapio;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager\Doctrine\NameProvider;
use Zeedhi\Framework\DataSource\FilterCriteria;

class ImportarCardapioDia {
    protected $utilities;
	protected $connection;
	protected $environment;
	protected $dataSourceName;
	protected $dataSourceManager;
	protected $utilitiesCard;
	protected $comensalEstimadoCardapio;
	protected $elaboracaoCardapio;

    public function __construct($connection, $utilities, $environment, $dataSourceManager, $utilitiesCard, $comensalEstimadoCardapio, $elaboracaoCardapio) {
        $this->connection  = $connection;
        $this->utilities = $utilities;
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->utilitiesCard = $utilitiesCard;
        $this->comensalEstimadoCardapio = $comensalEstimadoCardapio;
        $this->elaboracaoCardapio = $elaboracaoCardapio;
	}
	
	public function importarCardapio(DTO\Request\Row $request, DTO\Response $response) {
	    $row = $request->getRow();
	    try {
	    	$this->connection->beginTransaction();
		    foreach($row['dePara'] as $dePara) {
		    	$holiday = $this->hasHoliday($dePara, $row['formImport'], $row['filterData']);
		    	if (count($holiday) == 0) {
			    	$holiday = $this->hasHolidayAggregated($dePara, $row['formImport']);
			    	if (count($holiday) == 0) {
			    		$cardOrigin = $this->getCardOrigin($dePara, $row['formImport'], $row['filterData']);
			    		if (count($cardOrigin) > 0) {
			    			$compCard = $this->getCompCard($dePara, $row['formImport'], $row['filterData']);
			    			$cardDest = $this->getCardDest($dePara, $row['filterData']);
			    			$this->import($dePara, $cardOrigin, $cardDest, $compCard, $row['filterData'], $row['formImport']);
			    			$this->updateComenCentral($row['filterData'], $dePara);
			    		}
			    	}
		    	}
		    }
		    
		    $this->connection->commit();
		    $response->addDataSet(new DataSet("successImport", array(true)));
	    } catch (\Exception $e) {
	    	$response->setError(new Error($e->getMessage(), 500));
	    	$this->connection->rollback();
		}
	}
	
	// VERIFICA SE É FERIADO NO DIA ORIGEM
	private function hasHoliday($dePara, $formImport, $filterData) {
		$query = "SELECT DTFERIFILI, DSFERIFILI FROM FERIFILI WHERE CDFILIAL = :P_CDFILIAL AND DTFERIFILI = :P_DTCARDIAPME";
		$params = array(
			'P_CDFILIAL' => $filterData['aggregated'] != null ? $filterData['aggregated']['CDFILIAL'] : $formImport['CENTRAL'],
			'P_DTCARDIAPME' => substr($dePara['DE'], 0, 10)
		);
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
		
		return $stmt->fetchAll();
	}
	
	//VERIFICA SE É FERIADO NA AGREGADA DO DIA DE ORIGEM
	private function hasHolidayAggregated($dePara, $formImport) {
		$query = "SELECT * FROM (SELECT FILITIPOCARD.CDFILIAL, ( SELECT MAX(DTFERIFILI) FROM FERIFILI WHERE CDFILIAL = FILITIPOCARD.CDFILIAL AND DTFERIFILI = :P_DTCARDIAPME ) AS FERIADO, ( SELECT MAX(DTFERICARD) FROM FERICARD WHERE CDFILIAL = FILITIPOCARD.CDFILIAL AND DTFERICARD = :P_DTCARDIAPME ) AS FERICARD, ( SELECT MAX(IDCARDIAUTIL) FROM PARAMPLANEJA WHERE CDFILIAL = FILITIPOCARD.CDFILIAL AND CDPARPLANEJA = '1' ) AS IDCARDIAUTIL FROM FILITIPOCARD, SERVTIPOCARD, PARAMPLANEJA WHERE ( FILITIPOCARD.CDFILCENTPME = :P_CDFILCENTPME ) AND ( FILITIPOCARD.CDTIPOCARD = :P_CDTIPOCARD ) AND ( SERVTIPOCARD.CDFILCENTPME = FILITIPOCARD.CDFILCENTPME ) AND ( SERVTIPOCARD.CDTIPOCARD = FILITIPOCARD.CDTIPOCARD ) AND ( SERVTIPOCARD.CDSERVFILI = :P_CDSERVFILI ) AND ( FILITIPOCARD.CDFILIAL = PARAMPLANEJA.CDFILIAL ) AND FILITIPOCARD.IDTCARATFILI = 'S' AND NOT EXISTS ( SELECT 1 FROM CARDIAPME WHERE CDFILCENTPME = FILITIPOCARD.CDFILCENTPME AND NRCARDPME = :P_NRCARDPME AND CDSERVFILI = SERVTIPOCARD.CDSERVFILI AND CDFILIAL = FILITIPOCARD.CDFILIAL AND DTCARDIAPME = :P_DTCARDIAPME )) WHERE FERIADO IS NOT NULL OR FERICARD IS NOT NULL OR IDCARDIAUTIL = 'N'";
		$params = array(
			'P_CDTIPOCARD' => $formImport['TIPOCARD'],
			'P_NRCARDPME' => $formImport['NRCARDPME'],
			'P_CDFILCENTPME' => $formImport['CENTRAL'],
			'P_CDSERVFILI' => $formImport['SERVICO'],
			'P_DTCARDIAPME' => substr($dePara['DE'], 0, 10)
		);
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
		
		return $stmt->fetchAll();
	}
	
	// PEGA O CARDAPIO DE ORIGEM
	private function getCardOrigin($dePara, $formImport, $filterData) {
		$query = "SELECT CDFILCENTPME, NRCARDPME, NRCARDIAPME, CDSERVFILI, CDFILIAL, DTCARDIAPME, QTCOMESTCPME, QTCLIESTCPME, QTFUNESTCPME, QTDOAESTCPME, QTCOMEFECPME, QTCLIEFECPME, QTFUNEFECPME, QTDOAEFECPME, IDCARDESPEC FROM CARDIAPME WHERE CDFILCENTPME = :P_CDFILCENTPME AND NRCARDPME = :P_NRCARDPME AND CDSERVFILI = :P_CDSERVFILI AND CDFILIAL = :P_CDFILIAL AND DTCARDIAPME = :P_DTCARDIAPME";
		$params = array(
			'P_CDFILIAL'     => $formImport['CENTRAL'],
			'P_NRCARDPME'    => $formImport['NRCARDPME'],
			'P_CDFILCENTPME' => $formImport['CENTRAL'],
			'P_CDSERVFILI'   => $formImport['SERVICO'],
			'P_DTCARDIAPME'  => substr($dePara['DE'], 0, 10)
		);
		
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
		
		return $stmt->fetchAll();
	}
	
	// PEGA A COMPOSICAO DO CARDAPIO
	private function getCompCard($dePara, $formImport, $filterData) {
		$query = "SELECT CD.DTCARDIAPME, TP.NMTIPOPRAT, CC.NRCARDPME, CC.NRSEQPRACPME, CC.NRORDPRACPME, CC.CDTIPOPRAT, CC.CDFILAUXPRAT, CC.CDPRATO, PT.NMPRATO, CASE WHEN ( CD.TIPO = 'P' ) AND ( PP.VRPERACEIT IS NOT NULL ) AND ( PP.VRPERACEIT <> 0 ) THEN 100 * ( 1 - ( PP.VRPERACEIT / 100 ) * - 1 ) ELSE CC.VRPECONSCPME END                          AS PERCENTUAL, /*Pega comensais específicos, se não comensais da adesão dos pratos, se não comensais padrão*/ ( CASE WHEN ( CD.TIPO = 'P' ) AND ( PP.VRPERACEIT IS NOT NULL ) AND ( PP.VRPERACEIT <> 0 ) THEN 100 * ( 1 - ( PP.VRPERACEIT / 100 ) * - 1 ) ELSE CC.VRPECONSCPME END ) / 100 * CA.QTCOMESTCPME     AS COMENS FROM ( SELECT 'P' AS TIPO, CDFILCENTPME, NRCARDPME, NRCARDIAPME, CDSERVFILI, CDFILIAL, DTCARDIAPME FROM CARDIAPME P WHERE ( P.CDFILCENTPME = :P_CDFILCENTPME ) AND ( P.NRCARDPME = :P_NRCARDPME ) AND ( P.CDSERVFILI = :P_CDSERVFILI ) AND ( DTCARDIAPME = :P_DTCARDIAPME ) AND ( P.CDFILIAL = P.CDFILCENTPME ) AND NOT EXISTS ( SELECT CDFILIAL FROM CARDIAPME C WHERE ( C.CDFILCENTPME = P.CDFILCENTPME ) AND ( C.NRCARDPME = P.NRCARDPME ) AND ( C.CDSERVFILI = P.CDSERVFILI ) AND ( C.CDFILIAL = :P_CDFILIAL ) AND ( C.DTCARDIAPME = P.DTCARDIAPME ) AND ( C.IDCARDESPEC = 'S' ) ) UNION ALL SELECT 'E' AS TIPO, CDFILCENTPME, NRCARDPME, NRCARDIAPME, CDSERVFILI, CDFILIAL, DTCARDIAPME FROM CARDIAPME WHERE ( CDFILCENTPME = :P_CDFILCENTPME ) AND ( NRCARDPME = :P_NRCARDPME ) AND ( CDSERVFILI = :P_CDSERVFILI ) AND ( CDFILIAL = :P_CDFILIAL ) AND ( DTCARDIAPME = :P_DTCARDIAPME ) AND ( IDCARDESPEC = 'S' ) ) CD INNER JOIN COMPCARDPME    CC ON ( CC.CDFILCENTPME = CD.CDFILCENTPME ) AND ( CC.NRCARDPME = CD.NRCARDPME ) AND ( CC.NRCARDIAPME = CD.NRCARDIAPME ) INNER JOIN CARDIAPME      CA ON ( CA.CDFILCENTPME = CD.CDFILCENTPME ) AND ( CA.NRCARDPME = CD.NRCARDPME ) AND ( CA.CDSERVFILI = CD.CDSERVFILI ) AND ( CA.DTCARDIAPME = CD.DTCARDIAPME ) AND ( CA.CDFILIAL = :P_CDFILIAL ) INNER JOIN CONFCARDPME CNF ON CNF.CDFILCENTPME = CA.CDFILCENTPME AND CNF.NRCARDPME = CA.NRCARDPME AND CNF.CDSERVFILI = CA.CDSERVFILI AND CC.NRSEQPRACPME = CNF.NRSEQCNFCPME AND CC.NRORDPRACPME = CNF.NRORDCNFCPME AND CC.CDTIPOPRAT = CNF.CDTIPOPRAT INNER JOIN TIPOPRAT       TP ON ( TP.CDTIPOPRAT = CC.CDTIPOPRAT ) INNER JOIN PRATO          PT ON ( PT.CDFILAUXPRAT = CC.CDFILAUXPRAT ) AND ( PT.CDPRATO = CC.CDPRATO ) INNER JOIN CARDAPIOPME    CPME ON CPME.CDFILCENTPME = CD.CDFILCENTPME AND CPME.NRCARDPME = CD.NRCARDPME LEFT JOIN PERACEITPRATO  PP ON PP.CDFILCENTPME = :P_CDFILCENTPME AND PP.CDFILIAL = :P_CDFILIAL AND PP.CDPRATO = CC.CDPRATO AND PP.CDFILAUXPRAT = CC.CDFILAUXPRAT AND PP.CDTIPOCARD = CPME.CDTIPOCARD ORDER BY 4, 5";
		$params = array(
			'P_CDFILIAL'     => $formImport['CENTRAL'],
			'P_NRCARDPME'    => $formImport['NRCARDPME'],
			'P_CDFILCENTPME' => $formImport['CENTRAL'],
			'P_CDSERVFILI'   => $formImport['SERVICO'],
			'P_DTCARDIAPME'  => substr($dePara['DE'], 0, 10)
		);
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
		
		return $stmt->fetchAll();
	}
	
	// REALIZA O ARREDONDAMENTO DO COMENSAIS
	private function roundComen($dePara, $formImport, $filterData) {
		$comenDest = $this->getComenDest($dePara, $filterData);
		$plateDest = $this->getPlateOrigin($dePara, $formImport, $filterData);
		
		if (count($plateDest) > 0 && count($comenDest) > 0) {
			$valor = ($plateDest[0]['VRPECONSCPME'] * $comenDest[0]['QTCOMESTCPME']) / 100;
			
			if (intval($formImport['ARREDONDAR']) != 0) {
				$valorInteiro = $valor / intval($formImport['ARREDONDAR']);
				$valorFracionado = $valor % intval($formImport['ARREDONDAR']);
				
				if($valorFracionado > 0) $valor = ($valorInteiro + 1) * intval($formImport['ARREDONDAR']);
				else $valor = $valorInteiro * intval($formImport['ARREDONDAR']);
				
				return $this->calculoPercent($valor, $comenDest[0]['QTCOMESTCPME']);
			}
		}
		
		$valor = 0;
		if (count($comenDest) > 0) {
			if ($comenDest[0]['QTCOMESTCPME'] != 0) $valor = $this->calculoPercent($comenDest[0]['QTCOMESTCPME'], $comenDest[0]['QTCOMESTCPME']);
		}
		return $valor;
	}
	
	private function calculoPercent($valor, $comensal) {
		if ($comensal == 0) return 0;
		return ($valor * 100) / $comensal;
	}
	
	// PEGA O COMENSAIS DA DATA DESTINO
	private function getComenDest($dePara, $filterData) {
		$query = "SELECT NRCARDIAPME, QTCOMESTCPME FROM CARDIAPME WHERE NRCARDPME = :P_NRCARDPME AND CDFILCENTPME = :P_CDFILCENTPME AND CDFILIAL = :P_CDFILIAL AND CDSERVFILI = :P_CDSERVFILI AND DTCARDIAPME = :P_DTCARDIAPME";
		$params = array(
			'P_CDFILIAL' => $filterData['aggregated'] != null ? $filterData['aggregated']['CDFILIAL'] : $filterData['cdfilcentpme'],
			'P_NRCARDPME' => $filterData['NRCARDPME'],
			'P_CDFILCENTPME' => $filterData['cdfilcentpme'],
			'P_CDSERVFILI' => $filterData['service']['CDSERVFILI'],
			'P_DTCARDIAPME' => substr($dePara['PARA'], 0, 10)
		);
		
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
		
		return $stmt->fetchAll();
	}
	
	// PEGA OS PRATOS DA DATA DE ORIGEM
	private function getPlateOrigin($dePara, $formImport, $filterData) {
		$query = "SELECT CD.CDFILIAL, CD.DTCARDIAPME, CD.NRCARDIAPME, TP.NMTIPOPRAT, PT.NMPRATO, CD.QTCOMESTCPME, CP.CDFILAUXPRAT, CP.CDPRATO, CP.VRPECONSCPME, CP.CDTIPOPRAT, CP.NRSEQPRACPME, CP.NRORDPRACPME, CD.NRORG FROM CARDIAPME CD, COMPCARDPME CP, TIPOPRAT TP, PRATO PT WHERE CD.NRORG    = :NRORG    AND CD.NRCARDPME    = :P_NRCARDPME    AND CD.CDFILCENTPME = :P_CDFILCENTPME AND CD.CDFILIAL     = CD.CDFILCENTPME AND CD.CDSERVFILI   = :P_CDSERVFILI   AND CD.DTCARDIAPME  = :P_DTCARDIAPME AND CD.NRCARDPME    = CP.NRCARDPME    AND CD.NRCARDIAPME  = CP.NRCARDIAPME  AND CD.CDFILCENTPME = CP.CDFILCENTPME AND TP.CDTIPOPRAT   = CP.CDTIPOPRAT   AND PT.CDFILAUXPRAT = CP.CDFILAUXPRAT AND PT.CDPRATO      = CP.CDPRATO      AND NOT EXISTS (SELECT CP.DTCARDIAPME FROM CARDIAPME CP, COMPCARDPME CC, TIPOPRAT TP, PRATO PT WHERE CP.NRCARDPME    = :P_NRCARDPME    AND CP.CDFILCENTPME = :P_CDFILCENTPME AND CP.CDFILIAL     = :P_CDFILAGREG   AND CP.CDSERVFILI   = :P_CDSERVFILI   AND CP.DTCARDIAPME  = :P_DTCARDIAPME AND CP.NRCARDPME    = CC.NRCARDPME    AND CP.NRCARDIAPME  = CC.NRCARDIAPME  AND CP.CDFILCENTPME = CC.CDFILCENTPME AND TP.CDTIPOPRAT   = CC.CDTIPOPRAT   AND PT.CDFILAUXPRAT = CC.CDFILAUXPRAT AND PT.CDPRATO      = CC.CDPRATO      AND CD.NRCARDPME    = CP.NRCARDPME    AND CD.CDFILCENTPME = CP.CDFILCENTPME AND CD.CDSERVFILI   = CP.CDSERVFILI   AND CD.DTCARDIAPME  = CP.DTCARDIAPME) UNION ALL SELECT CD.CDFILIAL, CD.DTCARDIAPME, CD.NRCARDIAPME, TP.NMTIPOPRAT, PT.NMPRATO, CD.QTCOMESTCPME, CP.CDFILAUXPRAT, CP.CDPRATO, CP.VRPECONSCPME, CP.CDTIPOPRAT, CP.NRSEQPRACPME, CP.NRORDPRACPME, CD.NRORG FROM CARDIAPME CD, COMPCARDPME CP, TIPOPRAT TP, PRATO PT WHERE CD.NRORG    = :NRORG    AND CD.NRCARDPME    = :P_NRCARDPME    AND CD.CDFILCENTPME = :P_CDFILCENTPME AND CD.CDFILIAL     = :P_CDFILAGREG   AND CD.CDSERVFILI   = :P_CDSERVFILI   AND CD.DTCARDIAPME  = :P_DTCARDIAPME AND CD.NRCARDPME    = CP.NRCARDPME    AND CD.NRCARDIAPME  = CP.NRCARDIAPME  AND CD.CDFILCENTPME = CP.CDFILCENTPME AND TP.CDTIPOPRAT   = CP.CDTIPOPRAT   AND PT.CDFILAUXPRAT = CP.CDFILAUXPRAT AND PT.CDPRATO      = CP.CDPRATO ORDER BY 2, 12";
		$params = array(
			'NRORG' => $this->environment->getNrOrg(),
			'P_CDFILAGREG'   => $filterData['aggregated'] != null ? $filterData['aggregated']['CDFILIAL'] : $formImport['CENTRAL'],
			'P_NRCARDPME'    => $formImport['NRCARDPME'],
			'P_CDFILCENTPME' => $formImport['CENTRAL'],
			'P_CDSERVFILI'   => $formImport['SERVICO'],
			'P_DTCARDIAPME'  => substr($dePara['DE'], 0, 10)
		);
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
		
		return $stmt->fetchAll();
	}
	
	// PEGA O CARDAPIO DA DATA DE DESTINO
	private function getCardDest($dePara, $filterData) {
		$query = "SELECT CM.CDTIPOPRAT, CC.CDFILAUXPRAT, CC.CDPRATO, CC.VRPECONSCPME, CM.NRSEQCNFCPME, CM.NRORDCNFCPME, CC.NRCARDIAPME, CC.NRSEQPRACPME, CC.NRORDPRACPME FROM (SELECT C.CDTIPOPRAT, C.CDFILAUXPRAT, C.CDPRATO, C.VRPECONSCPME, C.NRSEQPRACPME, C.NRORDPRACPME, C.NRCARDIAPME FROM CARDIAPME CD, COMPCARDPME C WHERE CD.NRCARDPME    = :P_NRCARDPME    AND CD.CDFILCENTPME = :P_CDFILCENTPME AND CD.CDFILIAL     = :P_CDFILIAL     AND CD.CDSERVFILI   = :P_CDSERVFILI   AND CD.DTCARDIAPME  = :P_DTCARDIAPME  AND CD.NRCARDPME    = C.NRCARDPME     AND CD.CDFILCENTPME = C.CDFILCENTPME  AND CD.NRCARDIAPME  = C.NRCARDIAPME) CC, CONFCARDPME CM WHERE CM.NRCARDPME    = :P_NRCARDPME    AND CM.CDFILCENTPME = :P_CDFILCENTPME AND CM.CDSERVFILI   = :P_CDSERVFILI   AND CM.NRSEQCNFCPME = CC.NRSEQPRACPME(+) ORDER BY CM.NRORDCNFCPME";
		$params = array(
			'P_CDFILIAL'     => $filterData['aggregated'] != null ? $filterData['aggregated']['CDFILIAL'] : $filterData['cdfilcentpme'],
			'P_NRCARDPME'    => $filterData['NRCARDPME'],
			'P_CDFILCENTPME' => $filterData['cdfilcentpme'],
			'P_CDSERVFILI'   => $filterData['service']['CDSERVFILI'],
			'P_DTCARDIAPME'  => substr($dePara['PARA'], 0, 10)
		);
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
		
		return $stmt->fetchAll();
	}
	
	private function import($dePara, $cardOrigin, $cardDest, $compCard, $filterData, $formImport) {
		$tpPratDest = $this->getTpPrat($cardDest);
		$tpPratOrigem = $this->getTpPrat($compCard);

		foreach($tpPratOrigem as $pratOrigem) {
			$key = array_search($pratOrigem, $tpPratDest);
			if (gettype($key) == "integer") {
				$keyCompCard = array_search($pratOrigem, array_column($compCard, 'CDTIPOPRAT'));
				$compOrigin = $compCard[$keyCompCard];
				
				$filial = ($filterData['aggregated'] == NULL) ? $filterData['cdfilcentpme'] : $filterData['aggregated']['CDFILIAL'];
				$cardia = $this->utilitiesCard->getCadiaPme($filterData['cdfilcentpme'], $filterData['NRCARDPME'], $filterData['service']['CDSERVFILI'], substr($dePara['PARA'], 0, 10), $filial);
				
				if(count($cardia) == 0) {
					$row = array (
						'filterData' => $filterData,
						'WEEKDAY' => $this->getWeekday(substr($dePara['PARA'], 0, 10)),
						'DTCARDIAPME' => substr($dePara['PARA'], 0, 10),
						'IDCARDESPEC' => ($filterData['aggregated'] != null) ? 'S' : 'N'
					);
					$cardia = $this->elaboracaoCardapio->insertInCardia($row);
				} else if ($filterData['aggregated'] != NULL) {
					$this->utilitiesCard->updateCardiaPme('S', $cardia[0]['CDFILCENTPME'], $cardia[0]['NRCARDPME'], $cardia[0]['NRCARDIAPME'], $cardia[0]['CDSERVFILI'], $cardia[0]['DTCARDIAPME'], $cardia[0]['CDFILIAL']);
				}
				
				$comenRounded = $this->roundComen($dePara, $formImport, $filterData);
				if ($comenRounded > 0) $this->insertPlate($cardDest[$key], $compOrigin, $formImport, $cardia, $comenRounded);
				else $this->utilitiesCard->deleteCardia($cardia[0]);
				unset($tpPratDest[$key]);
				array_splice($compCard, $keyCompCard, 1);
			}
		}
	}
	
	private function insertPlate($cardDest, $compOrigin, $formImport, $cardia, $comenRounded) {
		$cdfilcentpme = $cardia[0]['CDFILCENTPME'];
		$nrcardpme = $cardia[0]['NRCARDPME'];
		$nrcardiapme = $cardia[0]['NRCARDIAPME'];
		$nrseqcnfcpm = $cardDest['NRSEQCNFCPME']; 
		$cdfilauxprat = $compOrigin['CDFILAUXPRAT'];
		$cdprat = $compOrigin['CDPRATO'];
		$cdtipoprat = $compOrigin['CDTIPOPRAT'];
		$vrpeconscpm = $comenRounded;
		$nrordcnfcpme = $cardDest['NRORDCNFCPME'];
		if(strlen($cardDest['CDPRATO']) == 0) {
			$this->utilitiesCard->insertCompCard($cdfilcentpme, $nrcardpme, $nrcardiapme, $nrseqcnfcpm, $cdfilauxprat, $cdprat, $cdtipoprat, $vrpeconscpm, $nrordcnfcpme);
		} else if($formImport['RADIOSELECT'] == 'S') {
			$this->utilitiesCard->deleteCompCard($cdfilcentpme, $nrcardpme, $nrcardiapme, $nrseqcnfcpm, $cdtipoprat);
			$this->utilitiesCard->insertCompCard($cdfilcentpme, $nrcardpme, $nrcardiapme, $nrseqcnfcpm, $cdfilauxprat, $cdprat, $cdtipoprat, $vrpeconscpm, $nrordcnfcpme);
		}
	}
	
	private function getTpPrat($cardDest) {
		$arr = array();
		foreach($cardDest as $dest) {
			array_push($arr, $dest['CDTIPOPRAT']);
		}
		return $arr;
	}
	
	private function updateComenCentral ($filterData, $dePara) {
		$row = array(
			'CDFILCENTPME' => $filterData['cdfilcentpme'],
			'NRCARDPME'    => $filterData['NRCARDPME'],
			'CDSERVFILI'   => $filterData['service']['CDSERVFILI'],
			'DTCARDIAPME'  => substr($dePara['PARA'], 0, 10)
		);
		$this->comensalEstimadoCardapio->updateComenCentral($row);
	}
	
	private function getWeekday($date) {
		$date = $this->tranformInAmericanDate($date);
		return date('w', strtotime($date));
	}
	
	private function tranformInAmericanDate($date) {
		$newDate = explode("/", $date);	
		return $newDate[2].'-'.$newDate[1].'-'.$newDate[0];
	}
}