import {
  IEventParam,
  Loader,
  Metadata,
  IDictionary,
  Datasource,
  Http,
  dayjs as moment,
} from '@zeedhi/core';

import {
  GridEditable, Form, Card, TextInput, IComponentRender,
} from '@zeedhi/common';
  
export class Ger02500NutrientesController {
  private nutriIsVisible = false;
  
  public gridEditController = Loader.getInstance('GridEditableController');

  public crudController = Loader.getInstance('CrudController');
  
  public modalController = Loader.getInstance('ModalController');

  public utilities = Loader.getInstance('Utilities');

  public fillCode({ component }: IDictionary) {
    if (component.name === 'CDNUTRIENTE_editable_undefined') {
      if (component.value < 0) component.value = '0';
      component.value = component.value.padStart(3, '0');
    } else {
      if (component.value < 0) component.value = '0';
      component.value = component.value.padStart(2, '0');
    }
  }
  
  public toUpperCase({ component }: IEventParam<TextInput>) {
    component.value = component.value.toUpperCase();
  }
  
  public onChangeGrupNutriCurrentRow({ component }: IEventParam<Datasource>) {
    const colunaGrupNutri = component.currentRow.CDGRUPNUTR;
    
    if (colunaGrupNutri) {
      const gridNutri = Metadata.getInstance<GridEditable>('nutrienteGridDetail');
      
      const conditions = [
        {
          name: 'CDGRUPNUTR',
          operator: '=',
          value: component.currentRow.CDGRUPNUTR,
        },
      ];
      
      gridNutri.datasource.filter = conditions;
      gridNutri.datasource.get();
      this.cardNutriVisible();
    }
  }
  
  private cardNutriVisible() {
    const card = Metadata.getInstance<Card>('nutrienteCard');
    try {
      if (!this.gridEditController.newRow) {
        card.isVisible = true;
        this.nutriIsVisible = true;
      }
    } catch (Error) {
      card.isVisible = false;
      this.nutriIsVisible = false;
    }
  }
  
  public closeCardNutri() {
    const card = Metadata.getInstance<Card>('nutrienteCard');
    
    card.isVisible = false;
    this.nutriIsVisible = false;
  }
  
  public createModal() {
    this.modalController.createModal('/modals/formTpCardapio');
  }
  
  get gridColsReturnValue(): number {
    return this.nutriIsVisible ? 6 : 12;
  }

  public saveGrupoNutrientes() {
    const form = Metadata.getInstance<Form>('formGrupoNutri');
    const gridGrupoNutri: GridEditable = Metadata.getInstance('gridGrupoNutri');
    const editedRows: IDictionary = gridGrupoNutri.getEditedRows();
    if (form.validate() && editedRows.length > 0) {
      const gridNutrientes: GridEditable = Metadata.getInstance('gridNutrientes');
      
      editedRows.forEach((row: IDictionary) => {
        if (row.__is_new) {
          row.CDGRUPNUTR = row.CDGRUPNUTR.padStart(2, '0');
          row.DTULTATUGRNU = moment().format('DD/MM/YYYY');
        }
      });

      this.crudController.saveRows(editedRows, 'grupnutr', gridGrupoNutri).then(() => {
        this.gridEditController.defaultState(gridGrupoNutri);
        gridNutrientes.datasource.get();
        this.utilities.showAlert('alert', 'pme::salvoComSucesso', 'success');
      }).catch((error: string) => {
        this.utilities.showAlert('alert', `pme::${error}`, 'error');
      });
    }
  }
  
  public getMaxSeq() {
    return Http.get('maxOrdemNutriente').then((response) => {
      const max = response.data.data[0]?.MAXNRORDEMNUTR;
      return max;
    });
  }
  
  private cancelActionsAfterDrag(gridNutriente: GridEditable) {
    const toolbarSlot = gridNutriente.toolbarSlot;
    toolbarSlot.forEach((e: IComponentRender) => {
      if (e.name === 'cancelButton') e.disabled = true;
      if (e.name === 'saveButton') e.disabled = true;
    });
  }
  
  public saveNutrientes() {
    const form = Metadata.getInstance<Form>('formNutrientes');
    const gridNutrientes: GridEditable = Metadata.getInstance('gridNutrientes');
    const editedRows: IDictionary = gridNutrientes.getEditedRows();
    
    if (form.validate() && editedRows.length > 0) {
      const gridNutrienteDetail: GridEditable = Metadata.getInstance('nutrienteGridDetail');
      
      this.getMaxSeq().then((maxOrdemNutriente) => {
        editedRows.forEach((row: IDictionary) => {
          if (row.__is_new) {
            row.CDNUTRIENTE = row.CDNUTRIENTE.padStart(3, '0');
            row.NMREDUZIDO = row.NMREDUZIDO.toUpperCase();
            row.IDCALORIAS = 'N';
            row.IDNUTRRELEV = row.IDNUTRRELEV ? row.IDNUTRRELEV : 'N';
            row.IDTIPONUTR = 'N';
            row.VRFATORNUTR = null;
            row.IDKCAL = 'N';
            row.NRORDEMNUTR = row.NRORDEMNUTR ? parseInt(row.NRORDEMNUTR, 10) : maxOrdemNutriente + 1;
            row.VRLIMDIARIONT = row.VRLIMDIARIONT ? parseInt(row.VRLIMDIARIONT, 10) : null;
          } else {
            row.NMREDUZIDO = row.NMREDUZIDO.toUpperCase();
          }
        
          this.crudController.saveRows(editedRows, 'nutriente', gridNutrientes).then(() => {
            this.gridEditController.defaultState(gridNutrientes).then(() => {
              this.cancelActionsAfterDrag(gridNutrientes);
            });
            gridNutrienteDetail.datasource.get();
            this.utilities.showAlert('alert', 'pme::salvoComSucesso', 'success');
          }).catch((error: string) => {
            this.utilities.showAlert('alert', `pme::${error}`, 'error');
          });
        });
      });
    }
  }
}
